GamsCbcOptions

Struct GamsCbcOptions 

pub struct GamsCbcOptions {
    pub raw: Vec<String>,
    /* private fields */
}
Options for GAMS/CBC. Reference: https://www.gams.com/latest/docs/S_CBC.html

Fields

raw: Vec<String>

Extra option-file lines written verbatim, for options without a generated setter (or values a setter can’t express).

Implementations

Source

impl GamsCbcOptions

pub fn reslim(self, v: impl Display) -> Self

Set GAMS option reslim. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn special(self, v: impl Display) -> Self

Set GAMS option special. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn writemps(self, v: impl Display) -> Self

Set GAMS option writemps. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn auto_scale(self, v: impl Display) -> Self

Set GAMS option autoScale. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn bias_lu(self, v: impl Display) -> Self

Set GAMS option biasLU. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn bscale(self, v: impl Display) -> Self

Set GAMS option bscale. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn crash(self, v: impl Display) -> Self

Set GAMS option crash. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn crossover(self, v: impl Display) -> Self

Set GAMS option crossover. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dense_threshold(self, v: impl Display) -> Self

Set GAMS option denseThreshold. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn factorization(self, v: impl Display) -> Self

Set GAMS option factorization. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn gamma(self, v: impl Display) -> Self

Set GAMS option gamma. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn idiot_crash(self, v: impl Display) -> Self

Set GAMS option idiotCrash. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn iterlim(self, v: impl Display) -> Self

Set GAMS option iterlim. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn kkt(self, v: impl Display) -> Self

Set GAMS option KKT. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn max_factor(self, v: impl Display) -> Self

Set GAMS option maxFactor. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn pass_presolve(self, v: impl Display) -> Self

Set GAMS option passPresolve. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn perturbation(self, v: impl Display) -> Self

Set GAMS option perturbation. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn presolve(self, v: impl Display) -> Self

Set GAMS option presolve. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_weight(self, v: impl Display) -> Self

Set GAMS option primalWeight. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn psi(self, v: impl Display) -> Self

Set GAMS option psi. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn random_seed_clp(self, v: impl Display) -> Self

Set GAMS option randomSeedClp. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn small_factorization(self, v: impl Display) -> Self

Set GAMS option smallFactorization. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn sparse_factor(self, v: impl Display) -> Self

Set GAMS option sparseFactor. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn sprint_crash(self, v: impl Display) -> Self

Set GAMS option sprintCrash. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn substitution(self, v: impl Display) -> Self

Set GAMS option substitution. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn tol_dual(self, v: impl Display) -> Self

Set GAMS option tol_dual. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn tol_presolve(self, v: impl Display) -> Self

Set GAMS option tol_presolve. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn tol_primal(self, v: impl Display) -> Self

Set GAMS option tol_primal. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn cutoff(self, v: impl Display) -> Self

Set GAMS option cutoff. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn cutoff_constraint(self, v: impl Display) -> Self

Set GAMS option cutoffConstraint. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dumpsolutions(self, v: impl Display) -> Self

Set GAMS option dumpsolutions. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dumpsolutionsmerged(self, v: impl Display) -> Self

Set GAMS option dumpsolutionsmerged. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn expensive_strong(self, v: impl Display) -> Self

Set GAMS option expensiveStrong. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn extra_variables(self, v: impl Display) -> Self

Set GAMS option extraVariables. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn fix_on_dj(self, v: impl Display) -> Self

Set GAMS option fixOnDj. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn increment(self, v: impl Display) -> Self

Set GAMS option increment. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn infeasibility_weight(self, v: impl Display) -> Self

Set GAMS option infeasibilityWeight. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn loglevel(self, v: impl Display) -> Self

Set GAMS option loglevel. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn maxsol(self, v: impl Display) -> Self

Set GAMS option maxsol. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mipstart(self, v: impl Display) -> Self

Set GAMS option mipstart. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn multiple_root_passes(self, v: impl Display) -> Self

Set GAMS option multipleRootPasses. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn node_strategy(self, v: impl Display) -> Self

Set GAMS option nodeStrategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn nodlim(self, v: impl Display) -> Self

Set GAMS option nodlim. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn optca(self, v: impl Display) -> Self

Set GAMS option optca. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn optcr(self, v: impl Display) -> Self

Set GAMS option optcr. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn orbital_branching(self, v: impl Display) -> Self

Set GAMS option OrbitalBranching. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn parallelmode(self, v: impl Display) -> Self

Set GAMS option parallelmode. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn preprocess(self, v: impl Display) -> Self

Set GAMS option preprocess. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn printfrequency(self, v: impl Display) -> Self

Set GAMS option printfrequency. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn random_seed_cbc(self, v: impl Display) -> Self

Set GAMS option randomSeedCbc. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn sollim(self, v: impl Display) -> Self

Set GAMS option sollim. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn solvefinal(self, v: impl Display) -> Self

Set GAMS option solvefinal. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn solvetrace(self, v: impl Display) -> Self

Set GAMS option solvetrace. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn solvetraceincumbent(self, v: impl Display) -> Self

Set GAMS option solvetraceincumbent. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn solvetracenodefreq(self, v: impl Display) -> Self

Set GAMS option solvetracenodefreq. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn solvetracetimefreq(self, v: impl Display) -> Self

Set GAMS option solvetracetimefreq. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn sos_prioritize(self, v: impl Display) -> Self

Set GAMS option sosPrioritize. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn strategy(self, v: impl Display) -> Self

Set GAMS option strategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn strong_branching(self, v: impl Display) -> Self

Set GAMS option strongBranching. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn threads(self, v: impl Display) -> Self

Set GAMS option threads. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn tol_integer(self, v: impl Display) -> Self

Set GAMS option tol_integer. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn trust_pseudo_costs(self, v: impl Display) -> Self

Set GAMS option trustPseudoCosts. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn clique_cuts(self, v: impl Display) -> Self

Set GAMS option cliqueCuts. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn conflictcuts(self, v: impl Display) -> Self

Set GAMS option conflictcuts. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn cut_passes_root(self, v: impl Display) -> Self

Set GAMS option cut_passes_root. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn cut_passes_slow(self, v: impl Display) -> Self

Set GAMS option cut_passes_slow. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn cut_passes_tree(self, v: impl Display) -> Self

Set GAMS option cut_passes_tree. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn cut_depth(self, v: impl Display) -> Self

Set GAMS option cutDepth. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn cut_length(self, v: impl Display) -> Self

Set GAMS option cutLength. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn cuts(self, v: impl Display) -> Self

Set GAMS option cuts. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn flow_cover_cuts(self, v: impl Display) -> Self

Set GAMS option flowCoverCuts. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn gomory_cuts(self, v: impl Display) -> Self

Set GAMS option gomoryCuts. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn gomorycuts2(self, v: impl Display) -> Self

Set GAMS option gomorycuts2. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn knapsack_cuts(self, v: impl Display) -> Self

Set GAMS option knapsackCuts. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn lagomory_cuts(self, v: impl Display) -> Self

Set GAMS option lagomoryCuts. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn latwomir_cuts(self, v: impl Display) -> Self

Set GAMS option latwomirCuts. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn lift_and_project_cuts(self, v: impl Display) -> Self

Set GAMS option liftAndProjectCuts. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mir_cuts(self, v: impl Display) -> Self

Set GAMS option mirCuts. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn probing_cuts(self, v: impl Display) -> Self

Set GAMS option probingCuts. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn reduce_and_split_cuts(self, v: impl Display) -> Self

Set GAMS option reduceAndSplitCuts. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn reduce_and_split_cuts2(self, v: impl Display) -> Self

Set GAMS option reduceAndSplitCuts2. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn residual_capacity_cuts(self, v: impl Display) -> Self

Set GAMS option residualCapacityCuts. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn two_mir_cuts(self, v: impl Display) -> Self

Set GAMS option twoMirCuts. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn zero_half_cuts(self, v: impl Display) -> Self

Set GAMS option zeroHalfCuts. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn combine2solutions(self, v: impl Display) -> Self

Set GAMS option combine2Solutions. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn combine_solutions(self, v: impl Display) -> Self

Set GAMS option combineSolutions. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dins(self, v: impl Display) -> Self

Set GAMS option Dins. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dive_solves(self, v: impl Display) -> Self

Set GAMS option diveSolves. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn diving_coefficient(self, v: impl Display) -> Self

Set GAMS option DivingCoefficient. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn diving_fractional(self, v: impl Display) -> Self

Set GAMS option DivingFractional. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn diving_guided(self, v: impl Display) -> Self

Set GAMS option DivingGuided. This solver’s manual declares no type for it, so any Display value is accepted.

Set GAMS option DivingLineSearch. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn diving_pseudo_cost(self, v: impl Display) -> Self

Set GAMS option DivingPseudoCost. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn diving_random(self, v: impl Display) -> Self

Set GAMS option DivingRandom. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn diving_vector_length(self, v: impl Display) -> Self

Set GAMS option DivingVectorLength. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dw_heuristic(self, v: impl Display) -> Self

Set GAMS option dwHeuristic. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn feaspump(self, v: impl Display) -> Self

Set GAMS option feaspump. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn feaspump_artcost(self, v: impl Display) -> Self

Set GAMS option feaspump_artcost. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn feaspump_cutoff(self, v: impl Display) -> Self

Set GAMS option feaspump_cutoff. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn feaspump_fracbab(self, v: impl Display) -> Self

Set GAMS option feaspump_fracbab. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn feaspump_increment(self, v: impl Display) -> Self

Set GAMS option feaspump_increment. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn feaspump_passes(self, v: impl Display) -> Self

Set GAMS option feaspump_passes. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn greedy_heuristic(self, v: impl Display) -> Self

Set GAMS option greedyHeuristic. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn heuristics(self, v: impl Display) -> Self

Set GAMS option heuristics. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn h_options(self, v: impl Display) -> Self

Set GAMS option hOptions. This solver’s manual declares no type for it, so any Display value is accepted.

Set GAMS option localTreeSearch. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn naive_heuristics(self, v: impl Display) -> Self

Set GAMS option naiveHeuristics. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn pivot_and_complement(self, v: impl Display) -> Self

Set GAMS option pivotAndComplement. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn pivot_and_fix(self, v: impl Display) -> Self

Set GAMS option pivotAndFix. This solver’s manual declares no type for it, so any Display value is accepted.

Set GAMS option proximitySearch. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn randomized_rounding(self, v: impl Display) -> Self

Set GAMS option randomizedRounding. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn rens(self, v: impl Display) -> Self

Set GAMS option Rens. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn rins(self, v: impl Display) -> Self

Set GAMS option Rins. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn rounding_heuristic(self, v: impl Display) -> Self

Set GAMS option roundingHeuristic. This solver’s manual declares no type for it, so any Display value is accepted.

Set GAMS option VndVariableNeighborhoodSearch. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn vubheuristic(self, v: impl Display) -> Self

Set GAMS option vubheuristic. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn clocktype(self, v: GamsCbcClocktype) -> Self

Set GAMS option clocktype, restricted to its documented values.

pub fn dual_pivot(self, v: GamsCbcDualPivot) -> Self

Set GAMS option dualPivot, restricted to its documented values.

pub fn primal_pivot(self, v: GamsCbcPrimalPivot) -> Self

Set GAMS option primalPivot, restricted to its documented values.

pub fn scaling(self, v: GamsCbcScaling) -> Self

Set GAMS option scaling, restricted to its documented values.

pub fn startalg(self, v: GamsCbcStartalg) -> Self

Set GAMS option startalg, restricted to its documented values.

pub fn cost_strategy(self, v: GamsCbcCostStrategy) -> Self

Set GAMS option costStrategy, restricted to its documented values.