GamsCoptOptions

Struct GamsCoptOptions 

pub struct GamsCoptOptions {
    pub raw: Vec<String>,
    /* private fields */
}
Options for GAMS/COPT. Reference: https://www.gams.com/latest/docs/S_COPT.html

Fields

raw: Vec<String>

Extra option-file lines written verbatim, for options without a generated setter (or values a setter can’t express).

Implementations

Source

impl GamsCoptOptions

pub fn abs_gap(self, v: impl Display) -> Self

Set GAMS option AbsGap. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn bar_iter_limit(self, v: impl Display) -> Self

Set GAMS option BarIterLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_tol(self, v: impl Display) -> Self

Set GAMS option DualTol. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn feas_tol(self, v: impl Display) -> Self

Set GAMS option FeasTol. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn int_tol(self, v: impl Display) -> Self

Set GAMS option IntTol. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn matrix_tol(self, v: impl Display) -> Self

Set GAMS option MatrixTol. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn node_limit(self, v: impl Display) -> Self

Set GAMS option NodeLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn pdlpt_ol(self, v: impl Display) -> Self

Set GAMS option PDLPTol. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn q_matrix_tol(self, v: impl Display) -> Self

Set GAMS option QMatrixTol. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn rel_gap(self, v: impl Display) -> Self

Set GAMS option RelGap. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn sol_time_limit(self, v: impl Display) -> Self

Set GAMS option SolTimeLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn time_limit(self, v: impl Display) -> Self

Set GAMS option TimeLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dualize(self, v: impl Display) -> Self

Set GAMS option Dualize. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn presolve(self, v: impl Display) -> Self

Set GAMS option Presolve. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn scaling(self, v: impl Display) -> Self

Set GAMS option Scaling. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn bar_homogeneous(self, v: impl Display) -> Self

Set GAMS option BarHomogeneous. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn bar_order(self, v: impl Display) -> Self

Set GAMS option BarOrder. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn bar_start(self, v: impl Display) -> Self

Set GAMS option BarStart. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn crossover(self, v: impl Display) -> Self

Set GAMS option Crossover. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_perturb(self, v: impl Display) -> Self

Set GAMS option DualPerturb. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_price(self, v: impl Display) -> Self

Set GAMS option DualPrice. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn gpud_evice(self, v: impl Display) -> Self

Set GAMS option GPUDevice. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn gpum_ode(self, v: impl Display) -> Self

Set GAMS option GPUMode. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn lp_method(self, v: impl Display) -> Self

Set GAMS option LpMethod. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn req_farkas_ray(self, v: impl Display) -> Self

Set GAMS option ReqFarkasRay. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn conflict_analysis(self, v: impl Display) -> Self

Set GAMS option ConflictAnalysis. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn cut_level(self, v: impl Display) -> Self

Set GAMS option CutLevel. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn diving_heur_level(self, v: impl Display) -> Self

Set GAMS option DivingHeurLevel. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn fap_heur_level(self, v: impl Display) -> Self

Set GAMS option FAPHeurLevel. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn heur_level(self, v: impl Display) -> Self

Set GAMS option HeurLevel. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn linearize_indicators(self, v: impl Display) -> Self

Set GAMS option LinearizeIndicators. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn linearize_sos(self, v: impl Display) -> Self

Set GAMS option LinearizeSos. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_repair(self, v: impl Display) -> Self

Set GAMS option MipRepair. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_start_mode(self, v: impl Display) -> Self

Set GAMS option MipStartMode. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_start_node_limit(self, v: impl Display) -> Self

Set GAMS option MipStartNodeLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn node_cut_rounds(self, v: impl Display) -> Self

Set GAMS option NodeCutRounds. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn pre_root_heur_level(self, v: impl Display) -> Self

Set GAMS option PreRootHeurLevel. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn root_cut_level(self, v: impl Display) -> Self

Set GAMS option RootCutLevel. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn root_cut_rounds(self, v: impl Display) -> Self

Set GAMS option RootCutRounds. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn rounding_heur_level(self, v: impl Display) -> Self

Set GAMS option RoundingHeurLevel. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn strong_branching(self, v: impl Display) -> Self

Set GAMS option StrongBranching. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn sub_mip_heur_level(self, v: impl Display) -> Self

Set GAMS option SubMipHeurLevel. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn tree_cut_level(self, v: impl Display) -> Self

Set GAMS option TreeCutLevel. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_nlp_iter_limit(self, v: impl Display) -> Self

Set GAMS option MipNLPIterLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn nlp_iter_limit(self, v: impl Display) -> Self

Set GAMS option NLPIterLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn nlp_lin_scale(self, v: impl Display) -> Self

Set GAMS option NLPLinScale. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn nlp_mu_update(self, v: impl Display) -> Self

Set GAMS option NLPMuUpdate. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn nlpt_ol(self, v: impl Display) -> Self

Set GAMS option NLPTol. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn non_convex(self, v: impl Display) -> Self

Set GAMS option NonConvex. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn bar_threads(self, v: impl Display) -> Self

Set GAMS option BarThreads. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn concurrent_lp_mode(self, v: impl Display) -> Self

Set GAMS option ConcurrentLpMode. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn crossover_threads(self, v: impl Display) -> Self

Set GAMS option CrossoverThreads. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_tasks(self, v: impl Display) -> Self

Set GAMS option MipTasks. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn simplex_threads(self, v: impl Display) -> Self

Set GAMS option SimplexThreads. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn threads(self, v: impl Display) -> Self

Set GAMS option Threads. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn feaspref(self, v: impl Display) -> Self

Set GAMS option .feaspref. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn feas_relax(self, v: impl Display) -> Self

Set GAMS option FeasRelax. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn feas_relax_mode(self, v: impl Display) -> Self

Set GAMS option FeasRelaxMode. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn iis(self, v: impl Display) -> Self

Set GAMS option iis. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn iism_ethod(self, v: impl Display) -> Self

Set GAMS option IISMethod. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn tune_measure(self, v: impl Display) -> Self

Set GAMS option TuneMeasure. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn tune_method(self, v: impl Display) -> Self

Set GAMS option TuneMethod. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn tune_mode(self, v: impl Display) -> Self

Set GAMS option TuneMode. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn tune_output_level(self, v: impl Display) -> Self

Set GAMS option TuneOutputLevel. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn tune_params(self, v: impl Display) -> Self

Set GAMS option TuneParams. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn tune_permutes(self, v: impl Display) -> Self

Set GAMS option TunePermutes. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn tune_target_rel_gap(self, v: impl Display) -> Self

Set GAMS option TuneTargetRelGap. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn tune_target_time(self, v: impl Display) -> Self

Set GAMS option TuneTargetTime. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn tune_time_limit(self, v: impl Display) -> Self

Set GAMS option TuneTimeLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn tuning(self, v: impl Display) -> Self

Set GAMS option Tuning. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn log_level(self, v: impl Display) -> Self

Set GAMS option LogLevel. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn qextractalg(self, v: impl Display) -> Self

Set GAMS option qextractalg. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn readparams(self, v: impl Display) -> Self

Set GAMS option readparams. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn solnpool(self, v: impl Display) -> Self

Set GAMS option solnpool. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn solnpoolmerge(self, v: impl Display) -> Self

Set GAMS option solnpoolmerge. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn solvefinal(self, v: impl Display) -> Self

Set GAMS option solvefinal. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn solvetrace(self, v: impl Display) -> Self

Set GAMS option solvetrace. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn solvetraceincumbent(self, v: impl Display) -> Self

Set GAMS option solvetraceincumbent. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn solvetracenodefreq(self, v: impl Display) -> Self

Set GAMS option solvetracenodefreq. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn solvetracetimefreq(self, v: impl Display) -> Self

Set GAMS option solvetracetimefreq. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn writebas(self, v: impl Display) -> Self

Set GAMS option writebas. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn writebin(self, v: impl Display) -> Self

Set GAMS option writebin. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn writelp(self, v: impl Display) -> Self

Set GAMS option writelp. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn writemps(self, v: impl Display) -> Self

Set GAMS option writemps. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn writemst(self, v: impl Display) -> Self

Set GAMS option writemst. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn writenl(self, v: impl Display) -> Self

Set GAMS option writenl. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn qextractdenseswitchfactor(self, v: impl Display) -> Self

Set GAMS option qextractdenseswitchfactor. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn qextractdenseswitchlog(self, v: impl Display) -> Self

Set GAMS option qextractdenseswitchlog. This solver’s manual declares no type for it, so any Display value is accepted.