GamsHighsOptions

Struct GamsHighsOptions 

pub struct GamsHighsOptions {
    pub raw: Vec<String>,
    /* private fields */
}
Options for GAMS/HIGHS. Reference: https://www.gams.com/latest/docs/S_HIGHS.html

Fields

raw: Vec<String>

Extra option-file lines written verbatim, for options without a generated setter (or values a setter can’t express).

Implementations

Source

impl GamsHighsOptions

pub fn dual_feasibility_tolerance(self, v: impl Display) -> Self

Set GAMS option dual_feasibility_tolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_residual_tolerance(self, v: impl Display) -> Self

Set GAMS option dual_residual_tolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn hipo_block_size(self, v: impl Display) -> Self

Set GAMS option hipo_block_size. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn iis(self, v: impl Display) -> Self

Set GAMS option iis. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn iis_strategy(self, v: impl Display) -> Self

Set GAMS option iis_strategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn iis_time_limit(self, v: impl Display) -> Self

Set GAMS option iis_time_limit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn infinite_bound(self, v: impl Display) -> Self

Set GAMS option infinite_bound. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn infinite_cost(self, v: impl Display) -> Self

Set GAMS option infinite_cost. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn ipm_iteration_limit(self, v: impl Display) -> Self

Set GAMS option ipm_iteration_limit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn ipm_optimality_tolerance(self, v: impl Display) -> Self

Set GAMS option ipm_optimality_tolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn kkt_tolerance(self, v: impl Display) -> Self

Set GAMS option kkt_tolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn large_matrix_value(self, v: impl Display) -> Self

Set GAMS option large_matrix_value. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_abs_gap(self, v: impl Display) -> Self

Set GAMS option mip_abs_gap. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_allow_cut_separation_at_nodes(self, v: impl Display) -> Self

Set GAMS option mip_allow_cut_separation_at_nodes. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_allow_restart(self, v: impl Display) -> Self

Set GAMS option mip_allow_restart. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_detect_symmetry(self, v: impl Display) -> Self

Set GAMS option mip_detect_symmetry. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_feasibility_tolerance(self, v: impl Display) -> Self

Set GAMS option mip_feasibility_tolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_heuristic_effort(self, v: impl Display) -> Self

Set GAMS option mip_heuristic_effort. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_heuristic_run_feasibility_jump(self, v: impl Display) -> Self

Set GAMS option mip_heuristic_run_feasibility_jump. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_heuristic_run_rens(self, v: impl Display) -> Self

Set GAMS option mip_heuristic_run_rens. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_heuristic_run_rins(self, v: impl Display) -> Self

Set GAMS option mip_heuristic_run_rins. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_heuristic_run_root_reduced_cost(self, v: impl Display) -> Self

Set GAMS option mip_heuristic_run_root_reduced_cost. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_heuristic_run_shifting(self, v: impl Display) -> Self

Set GAMS option mip_heuristic_run_shifting. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_heuristic_run_zi_round(self, v: impl Display) -> Self

Set GAMS option mip_heuristic_run_zi_round. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_lifting_for_probing(self, v: impl Display) -> Self

Set GAMS option mip_lifting_for_probing. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_lp_age_limit(self, v: impl Display) -> Self

Set GAMS option mip_lp_age_limit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_max_improving_sols(self, v: impl Display) -> Self

Set GAMS option mip_max_improving_sols. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_max_leaves(self, v: impl Display) -> Self

Set GAMS option mip_max_leaves. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_max_nodes(self, v: impl Display) -> Self

Set GAMS option mip_max_nodes. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_max_stall_nodes(self, v: impl Display) -> Self

Set GAMS option mip_max_stall_nodes. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_max_start_nodes(self, v: impl Display) -> Self

Set GAMS option mip_max_start_nodes. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_min_cliquetable_entries_for_parallelism( self, v: impl Display, ) -> Self

Set GAMS option mip_min_cliquetable_entries_for_parallelism. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_min_logging_interval(self, v: impl Display) -> Self

Set GAMS option mip_min_logging_interval. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_pool_age_limit(self, v: impl Display) -> Self

Set GAMS option mip_pool_age_limit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_pool_soft_limit(self, v: impl Display) -> Self

Set GAMS option mip_pool_soft_limit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_pscost_minreliable(self, v: impl Display) -> Self

Set GAMS option mip_pscost_minreliable. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_rel_gap(self, v: impl Display) -> Self

Set GAMS option mip_rel_gap. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_root_presolve_only(self, v: impl Display) -> Self

Set GAMS option mip_root_presolve_only. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mipstart(self, v: impl Display) -> Self

Set GAMS option mipstart. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn objective_bound(self, v: impl Display) -> Self

Set GAMS option objective_bound. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn objective_target(self, v: impl Display) -> Self

Set GAMS option objective_target. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn optimality_tolerance(self, v: impl Display) -> Self

Set GAMS option optimality_tolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn output_flag(self, v: impl Display) -> Self

Set GAMS option output_flag. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn pdlp_cupdlpc_restart_method(self, v: impl Display) -> Self

Set GAMS option pdlp_cupdlpc_restart_method. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn pdlp_gpu(self, v: impl Display) -> Self

Set GAMS option pdlp_gpu. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn pdlp_iteration_limit(self, v: impl Display) -> Self

Set GAMS option pdlp_iteration_limit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn pdlp_optimality_tolerance(self, v: impl Display) -> Self

Set GAMS option pdlp_optimality_tolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn pdlp_restart_strategy(self, v: impl Display) -> Self

Set GAMS option pdlp_restart_strategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn pdlp_ruiz_iterations(self, v: impl Display) -> Self

Set GAMS option pdlp_ruiz_iterations. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn pdlp_scaling_mode(self, v: impl Display) -> Self

Set GAMS option pdlp_scaling_mode. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn pdlp_step_size_strategy(self, v: impl Display) -> Self

Set GAMS option pdlp_step_size_strategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_feasibility_tolerance(self, v: impl Display) -> Self

Set GAMS option primal_feasibility_tolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_residual_tolerance(self, v: impl Display) -> Self

Set GAMS option primal_residual_tolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn random_seed(self, v: impl Display) -> Self

Set GAMS option random_seed. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn sensitivity(self, v: impl Display) -> Self

Set GAMS option sensitivity. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn simplex_dual_edge_weight_strategy(self, v: impl Display) -> Self

Set GAMS option simplex_dual_edge_weight_strategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn simplex_iteration_limit(self, v: impl Display) -> Self

Set GAMS option simplex_iteration_limit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn simplex_max_concurrency(self, v: impl Display) -> Self

Set GAMS option simplex_max_concurrency. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn simplex_primal_edge_weight_strategy(self, v: impl Display) -> Self

Set GAMS option simplex_primal_edge_weight_strategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn simplex_scale_strategy(self, v: impl Display) -> Self

Set GAMS option simplex_scale_strategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn simplex_strategy(self, v: impl Display) -> Self

Set GAMS option simplex_strategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn simplex_update_limit(self, v: impl Display) -> Self

Set GAMS option simplex_update_limit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn small_matrix_value(self, v: impl Display) -> Self

Set GAMS option small_matrix_value. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn solution_file(self, v: impl Display) -> Self

Set GAMS option solution_file. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn solvetrace(self, v: impl Display) -> Self

Set GAMS option solvetrace. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn solvetraceincumbent(self, v: impl Display) -> Self

Set GAMS option solvetraceincumbent. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn solvetracenodefreq(self, v: impl Display) -> Self

Set GAMS option solvetracenodefreq. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn solvetracetimefreq(self, v: impl Display) -> Self

Set GAMS option solvetracetimefreq. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn threads(self, v: impl Display) -> Self

Set GAMS option threads. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn time_limit(self, v: impl Display) -> Self

Set GAMS option time_limit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn write_basis_file(self, v: impl Display) -> Self

Set GAMS option write_basis_file. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn write_iis_model_file(self, v: impl Display) -> Self

Set GAMS option write_iis_model_file. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn write_model_file(self, v: impl Display) -> Self

Set GAMS option write_model_file. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn write_solution_style(self, v: impl Display) -> Self

Set GAMS option write_solution_style. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn allow_unbounded_or_infeasible(self, v: impl Display) -> Self

Set GAMS option allow_unbounded_or_infeasible. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn allowed_cost_scale_factor(self, v: impl Display) -> Self

Set GAMS option allowed_cost_scale_factor. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn allowed_matrix_scale_factor(self, v: impl Display) -> Self

Set GAMS option allowed_matrix_scale_factor. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn centring_ratio_tolerance(self, v: impl Display) -> Self

Set GAMS option centring_ratio_tolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn cost_scale_factor(self, v: impl Display) -> Self

Set GAMS option cost_scale_factor. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_simplex_cost_perturbation_multiplier(self, v: impl Display) -> Self

Set GAMS option dual_simplex_cost_perturbation_multiplier. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_simplex_pivot_growth_tolerance(self, v: impl Display) -> Self

Set GAMS option dual_simplex_pivot_growth_tolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_steepest_edge_weight_error_tolerance(self, v: impl Display) -> Self

Set GAMS option dual_steepest_edge_weight_error_tolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_steepest_edge_weight_log_error_threshold( self, v: impl Display, ) -> Self

Set GAMS option dual_steepest_edge_weight_log_error_threshold. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn factor_pivot_threshold(self, v: impl Display) -> Self

Set GAMS option factor_pivot_threshold. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn factor_pivot_tolerance(self, v: impl Display) -> Self

Set GAMS option factor_pivot_tolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn highs_analysis_level(self, v: impl Display) -> Self

Set GAMS option highs_analysis_level. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn highs_debug_level(self, v: impl Display) -> Self

Set GAMS option highs_debug_level. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn icrash(self, v: impl Display) -> Self

Set GAMS option icrash. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn icrash_approx_iter(self, v: impl Display) -> Self

Set GAMS option icrash_approx_iter. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn icrash_breakpoints(self, v: impl Display) -> Self

Set GAMS option icrash_breakpoints. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn icrash_dualize(self, v: impl Display) -> Self

Set GAMS option icrash_dualize. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn icrash_exact(self, v: impl Display) -> Self

Set GAMS option icrash_exact. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn icrash_iterations(self, v: impl Display) -> Self

Set GAMS option icrash_iterations. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn icrash_starting_weight(self, v: impl Display) -> Self

Set GAMS option icrash_starting_weight. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn icrash_strategy(self, v: impl Display) -> Self

Set GAMS option icrash_strategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn ipx_dualize_strategy(self, v: impl Display) -> Self

Set GAMS option ipx_dualize_strategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn less_infeasible_dse_check(self, v: impl Display) -> Self

Set GAMS option less_infeasible_DSE_check. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn less_infeasible_dse_choose_row(self, v: impl Display) -> Self

Set GAMS option less_infeasible_DSE_choose_row. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn log_dev_level(self, v: impl Display) -> Self

Set GAMS option log_dev_level. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn lp_presolve_requires_basis_postsolve(self, v: impl Display) -> Self

Set GAMS option lp_presolve_requires_basis_postsolve. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn max_centring_steps(self, v: impl Display) -> Self

Set GAMS option max_centring_steps. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn max_dual_simplex_cleanup_level(self, v: impl Display) -> Self

Set GAMS option max_dual_simplex_cleanup_level. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn max_dual_simplex_phase1_cleanup_level(self, v: impl Display) -> Self

Set GAMS option max_dual_simplex_phase1_cleanup_level. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn mip_report_level(self, v: impl Display) -> Self

Set GAMS option mip_report_level. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn no_unnecessary_rebuild_refactor(self, v: impl Display) -> Self

Set GAMS option no_unnecessary_rebuild_refactor. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn presolve_pivot_threshold(self, v: impl Display) -> Self

Set GAMS option presolve_pivot_threshold. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn presolve_reduction_limit(self, v: impl Display) -> Self

Set GAMS option presolve_reduction_limit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn presolve_remove_slacks(self, v: impl Display) -> Self

Set GAMS option presolve_remove_slacks. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn presolve_rule_logging(self, v: impl Display) -> Self

Set GAMS option presolve_rule_logging. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn presolve_rule_off(self, v: impl Display) -> Self

Set GAMS option presolve_rule_off. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn presolve_substitution_maxfillin(self, v: impl Display) -> Self

Set GAMS option presolve_substitution_maxfillin. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_simplex_bound_perturbation_multiplier( self, v: impl Display, ) -> Self

Set GAMS option primal_simplex_bound_perturbation_multiplier. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn rebuild_refactor_solution_error_tolerance(self, v: impl Display) -> Self

Set GAMS option rebuild_refactor_solution_error_tolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn restart_presolve_reduction_limit(self, v: impl Display) -> Self

Set GAMS option restart_presolve_reduction_limit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn run_centring(self, v: impl Display) -> Self

Set GAMS option run_centring. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn simplex_crash_strategy(self, v: impl Display) -> Self

Set GAMS option simplex_crash_strategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn simplex_dualize_strategy(self, v: impl Display) -> Self

Set GAMS option simplex_dualize_strategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn simplex_initial_condition_check(self, v: impl Display) -> Self

Set GAMS option simplex_initial_condition_check. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn simplex_initial_condition_tolerance(self, v: impl Display) -> Self

Set GAMS option simplex_initial_condition_tolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn simplex_min_concurrency(self, v: impl Display) -> Self

Set GAMS option simplex_min_concurrency. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn simplex_permute_strategy(self, v: impl Display) -> Self

Set GAMS option simplex_permute_strategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn simplex_price_strategy(self, v: impl Display) -> Self

Set GAMS option simplex_price_strategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn simplex_unscaled_solution_strategy(self, v: impl Display) -> Self

Set GAMS option simplex_unscaled_solution_strategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn start_crossover_tolerance(self, v: impl Display) -> Self

Set GAMS option start_crossover_tolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn timeless_log(self, v: impl Display) -> Self

Set GAMS option timeless_log. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn use_implied_bounds_from_presolve(self, v: impl Display) -> Self

Set GAMS option use_implied_bounds_from_presolve. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn use_original_h_factor_logic(self, v: impl Display) -> Self

Set GAMS option use_original_HFactor_logic. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn hipo_ordering(self, v: GamsHighsHipoOrdering) -> Self

Set GAMS option hipo_ordering, restricted to its documented values.

pub fn hipo_parallel_type(self, v: GamsHighsHipoParallelType) -> Self

Set GAMS option hipo_parallel_type, restricted to its documented values.

pub fn hipo_system(self, v: GamsHighsHipoSystem) -> Self

Set GAMS option hipo_system, restricted to its documented values.

pub fn mip_ipm_solver(self, v: GamsHighsMipIpmSolver) -> Self

Set GAMS option mip_ipm_solver, restricted to its documented values.

pub fn mip_lp_solver(self, v: GamsHighsMipLpSolver) -> Self

Set GAMS option mip_lp_solver, restricted to its documented values.

pub fn parallel(self, v: GamsHighsParallel) -> Self

Set GAMS option parallel, restricted to its documented values.

pub fn presolve(self, v: GamsHighsPresolve) -> Self

Set GAMS option presolve, restricted to its documented values.

pub fn run_crossover(self, v: GamsHighsRunCrossover) -> Self

Set GAMS option run_crossover, restricted to its documented values.

pub fn solver(self, v: GamsHighsSolver) -> Self

Set GAMS option solver, restricted to its documented values.