GamsShotOptions

Struct GamsShotOptions 

pub struct GamsShotOptions {
    pub raw: Vec<String>,
    /* private fields */
}
Options for GAMS/SHOT. Reference: https://www.gams.com/latest/docs/S_SHOT.html

Fields

raw: Vec<String>

Extra option-file lines written verbatim, for options without a generated setter (or values a setter can’t express).

Implementations

Source

impl GamsShotOptions

pub fn output_debug_path(self, v: impl Display) -> Self

Set GAMS option Output.Debug.Path. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn output_gams_alternate_solutions_file(self, v: impl Display) -> Self

Set GAMS option Output.GAMS.AlternateSolutionsFile. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn output_console_iteration_detail(self, v: impl Display) -> Self

Set GAMS option Output.Console.Iteration.Detail. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn output_console_log_level(self, v: impl Display) -> Self

Set GAMS option Output.Console.LogLevel. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn output_console_dual_solver_show(self, v: impl Display) -> Self

Set GAMS option Output.Console.DualSolver.Show. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn output_console_primal_solver_show(self, v: impl Display) -> Self

Set GAMS option Output.Console.PrimalSolver.Show. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn output_debug_enable(self, v: impl Display) -> Self

Set GAMS option Output.Debug.Enable. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cplex_work_directory(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cplex.WorkDirectory. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_gams_nlp_options_filename(self, v: impl Display) -> Self

Set GAMS option Subsolver.GAMS.NLP.OptionsFilename. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_gams_nlp_solver(self, v: impl Display) -> Self

Set GAMS option Subsolver.GAMS.NLP.Solver. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cbc_node_strategy(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cbc.NodeStrategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cbc_scaling(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cbc.Scaling. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cbc_strategy(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cbc.Strategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cplex_feas_opt_mode(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cplex.FeasOptMode. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cplex_mip_emphasis(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cplex.MIPEmphasis. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cplex_memory_emphasis(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cplex.MemoryEmphasis. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cplex_node_file(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cplex.NodeFile. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cplex_numerical_emphasis(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cplex.NumericalEmphasis. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cplex_optimality_target(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cplex.OptimalityTarget. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cplex_parallel_mode(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cplex.ParallelMode. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cplex_probe(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cplex.Probe. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cplex_solution_pool_intensity(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cplex.SolutionPoolIntensity. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cplex_solution_pool_replace(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cplex.SolutionPoolReplace. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_gurobi_mip_focus(self, v: impl Display) -> Self

Set GAMS option Subsolver.Gurobi.MIPFocus. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_gurobi_numeric_focus(self, v: impl Display) -> Self

Set GAMS option Subsolver.Gurobi.NumericFocus. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_gurobi_pool_search_mode(self, v: impl Display) -> Self

Set GAMS option Subsolver.Gurobi.PoolSearchMode. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_gurobi_pool_solutions(self, v: impl Display) -> Self

Set GAMS option Subsolver.Gurobi.PoolSolutions. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_gurobi_scale_flag(self, v: impl Display) -> Self

Set GAMS option Subsolver.Gurobi.ScaleFlag. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_ipopt_linear_solver(self, v: impl Display) -> Self

Set GAMS option Subsolver.Ipopt.LinearSolver. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_ipopt_max_iterations(self, v: impl Display) -> Self

Set GAMS option Subsolver.Ipopt.MaxIterations. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_rootsearch_max_iterations(self, v: impl Display) -> Self

Set GAMS option Subsolver.Rootsearch.MaxIterations. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_rootsearch_method(self, v: impl Display) -> Self

Set GAMS option Subsolver.Rootsearch.Method. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cplex_solution_pool_gap(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cplex.SolutionPoolGap. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cplex_work_memory(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cplex.WorkMemory. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_gurobi_heuristics(self, v: impl Display) -> Self

Set GAMS option Subsolver.Gurobi.Heuristics. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_ipopt_constraint_violation_tolerance( self, v: impl Display, ) -> Self

Set GAMS option Subsolver.Ipopt.ConstraintViolationTolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_ipopt_relative_convergence_tolerance( self, v: impl Display, ) -> Self

Set GAMS option Subsolver.Ipopt.RelativeConvergenceTolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_rootsearch_active_constraint_tolerance( self, v: impl Display, ) -> Self

Set GAMS option Subsolver.Rootsearch.ActiveConstraintTolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_rootsearch_termination_tolerance(self, v: impl Display) -> Self

Set GAMS option Subsolver.Rootsearch.TerminationTolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_shot_reuse_hyperplanes_fraction(self, v: impl Display) -> Self

Set GAMS option Subsolver.SHOT.ReuseHyperplanes.Fraction. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cbc_auto_scale(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cbc.AutoScale. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cbc_deterministic_parallel_mode(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cbc.DeterministicParallelMode. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cplex_add_relaxed_lazy_constraints_as_local( self, v: impl Display, ) -> Self

Set GAMS option Subsolver.Cplex.AddRelaxedLazyConstraintsAsLocal. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_cplex_use_generic_callback(self, v: impl Display) -> Self

Set GAMS option Subsolver.Cplex.UseGenericCallback. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_shot_reuse_hyperplanes_use(self, v: impl Display) -> Self

Set GAMS option Subsolver.SHOT.ReuseHyperplanes.Use. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn subsolver_shot_use_fbbt(self, v: impl Display) -> Self

Set GAMS option Subsolver.SHOT.UseFBBT. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_cut_strategy(self, v: impl Display) -> Self

Set GAMS option Dual.CutStrategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_esh_interior_point_cutting_plane_iteration_limit( self, v: impl Display, ) -> Self

Set GAMS option Dual.ESH.InteriorPoint.CuttingPlane.IterationLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_esh_interior_point_cutting_plane_iteration_limit_subsolver( self, v: impl Display, ) -> Self

Set GAMS option Dual.ESH.InteriorPoint.CuttingPlane.IterationLimitSubsolver. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_esh_interior_point_use_primal_solution( self, v: impl Display, ) -> Self

Set GAMS option Dual.ESH.InteriorPoint.UsePrimalSolution. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_hyperplane_cuts_max_per_iteration(self, v: impl Display) -> Self

Set GAMS option Dual.HyperplaneCuts.MaxPerIteration. This solver’s manual declares no type for it, so any Display value is accepted.

Set GAMS option Dual.HyperplaneCuts.ObjectiveRootSearch. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_infeasibility_repair_iteration_limit( self, v: impl Display, ) -> Self

Set GAMS option Dual.MIP.InfeasibilityRepair.IterationLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_number_of_threads(self, v: impl Display) -> Self

Set GAMS option Dual.MIP.NumberOfThreads. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_presolve_frequency(self, v: impl Display) -> Self

Set GAMS option Dual.MIP.Presolve.Frequency. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_solution_limit_force_optimal_iteration( self, v: impl Display, ) -> Self

Set GAMS option Dual.MIP.SolutionLimit.ForceOptimal.Iteration. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_solution_limit_increase_iterations( self, v: impl Display, ) -> Self

Set GAMS option Dual.MIP.SolutionLimit.IncreaseIterations. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_solution_limit_initial(self, v: impl Display) -> Self

Set GAMS option Dual.MIP.SolutionLimit.Initial. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_solution_pool_capacity(self, v: impl Display) -> Self

Set GAMS option Dual.MIP.SolutionPool.Capacity. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_solver(self, v: impl Display) -> Self

Set GAMS option Dual.MIP.Solver. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_reduction_cut_max_iterations(self, v: impl Display) -> Self

Set GAMS option Dual.ReductionCut.MaxIterations. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_reduction_cut_strategy(self, v: impl Display) -> Self

Set GAMS option Dual.ReductionCut.Strategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_relaxation_frequency(self, v: impl Display) -> Self

Set GAMS option Dual.Relaxation.Frequency. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_relaxation_iteration_limit(self, v: impl Display) -> Self

Set GAMS option Dual.Relaxation.IterationLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_relaxation_max_lazy_constraints(self, v: impl Display) -> Self

Set GAMS option Dual.Relaxation.MaxLazyConstraints. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_tree_strategy(self, v: impl Display) -> Self

Set GAMS option Dual.TreeStrategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_esh_interior_point_cutting_plane_constraint_selection_factor( self, v: impl Display, ) -> Self

Set GAMS option Dual.ESH.InteriorPoint.CuttingPlane.ConstraintSelectionFactor. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_esh_interior_point_cutting_plane_termination_tolerance_abs( self, v: impl Display, ) -> Self

Set GAMS option Dual.ESH.InteriorPoint.CuttingPlane.TerminationToleranceAbs. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_esh_interior_point_cutting_plane_termination_tolerance_rel( self, v: impl Display, ) -> Self

Set GAMS option Dual.ESH.InteriorPoint.CuttingPlane.TerminationToleranceRel. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_esh_interior_point_cutting_plane_time_limit( self, v: impl Display, ) -> Self

Set GAMS option Dual.ESH.InteriorPoint.CuttingPlane.TimeLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_esh_interior_point_minimax_objective_lower_bound( self, v: impl Display, ) -> Self

Set GAMS option Dual.ESH.InteriorPoint.MinimaxObjectiveLowerBound. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_esh_interior_point_minimax_objective_upper_bound( self, v: impl Display, ) -> Self

Set GAMS option Dual.ESH.InteriorPoint.MinimaxObjectiveUpperBound. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_esh_rootsearch_constraint_tolerance(self, v: impl Display) -> Self

Set GAMS option Dual.ESH.Rootsearch.ConstraintTolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_hyperplane_cuts_constraint_selection_factor( self, v: impl Display, ) -> Self

Set GAMS option Dual.HyperplaneCuts.ConstraintSelectionFactor. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_hyperplane_cuts_max_constraint_factor(self, v: impl Display) -> Self

Set GAMS option Dual.HyperplaneCuts.MaxConstraintFactor. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_cut_off_initial_value(self, v: impl Display) -> Self

Set GAMS option Dual.MIP.CutOff.InitialValue. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_cut_off_tolerance(self, v: impl Display) -> Self

Set GAMS option Dual.MIP.CutOff.Tolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_infeasibility_repair_time_limit(self, v: impl Display) -> Self

Set GAMS option Dual.MIP.InfeasibilityRepair.TimeLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_node_limit(self, v: impl Display) -> Self

Set GAMS option Dual.MIP.NodeLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_optimality_tolerance(self, v: impl Display) -> Self

Set GAMS option Dual.MIP.OptimalityTolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_solution_limit_force_optimal_time(self, v: impl Display) -> Self

Set GAMS option Dual.MIP.SolutionLimit.ForceOptimal.Time. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_solution_limit_update_tolerance(self, v: impl Display) -> Self

Set GAMS option Dual.MIP.SolutionLimit.UpdateTolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_reduction_cut_reduction_factor(self, v: impl Display) -> Self

Set GAMS option Dual.ReductionCut.ReductionFactor. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_relaxation_termination_tolerance(self, v: impl Display) -> Self

Set GAMS option Dual.Relaxation.TerminationTolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_relaxation_time_limit(self, v: impl Display) -> Self

Set GAMS option Dual.Relaxation.TimeLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_esh_interior_point_cutting_plane_reuse( self, v: impl Display, ) -> Self

Set GAMS option Dual.ESH.InteriorPoint.CuttingPlane.Reuse. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_esh_rootsearch_unique_constraints(self, v: impl Display) -> Self

Set GAMS option Dual.ESH.Rootsearch.UniqueConstraints. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_esh_rootsearch_use_max_function(self, v: impl Display) -> Self

Set GAMS option Dual.ESH.Rootsearch.UseMaxFunction. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_hyperplane_cuts_delay(self, v: impl Display) -> Self

Set GAMS option Dual.HyperplaneCuts.Delay. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_hyperplane_cuts_save_hyperplane_points( self, v: impl Display, ) -> Self

Set GAMS option Dual.HyperplaneCuts.SaveHyperplanePoints. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_hyperplane_cuts_use_integer_cuts(self, v: impl Display) -> Self

Set GAMS option Dual.HyperplaneCuts.UseIntegerCuts. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_cut_off_use_initial_value(self, v: impl Display) -> Self

Set GAMS option Dual.MIP.CutOff.UseInitialValue. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_infeasibility_repair_integer_cuts(self, v: impl Display) -> Self

Set GAMS option Dual.MIP.InfeasibilityRepair.IntegerCuts. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_infeasibility_repair_use(self, v: impl Display) -> Self

Set GAMS option Dual.MIP.InfeasibilityRepair.Use. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_presolve_remove_redundant_constraints( self, v: impl Display, ) -> Self

Set GAMS option Dual.MIP.Presolve.RemoveRedundantConstraints. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_presolve_update_obtained_bounds(self, v: impl Display) -> Self

Set GAMS option Dual.MIP.Presolve.UpdateObtainedBounds. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_mip_update_objective_bounds(self, v: impl Display) -> Self

Set GAMS option Dual.MIP.UpdateObjectiveBounds. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_reduction_cut_use(self, v: impl Display) -> Self

Set GAMS option Dual.ReductionCut.Use. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn dual_relaxation_use(self, v: impl Display) -> Self

Set GAMS option Dual.Relaxation.Use. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_bound_tightening_feasibility_based_max_iterations( self, v: impl Display, ) -> Self

Set GAMS option Model.BoundTightening.FeasibilityBased.MaxIterations. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_bound_tightening_initial_poa_cut_strategy( self, v: impl Display, ) -> Self

Set GAMS option Model.BoundTightening.InitialPOA.CutStrategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_bound_tightening_initial_poa_iteration_limit( self, v: impl Display, ) -> Self

Set GAMS option Model.BoundTightening.InitialPOA.IterationLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_bound_tightening_initial_poa_stagnation_iteration_limit( self, v: impl Display, ) -> Self

Set GAMS option Model.BoundTightening.InitialPOA.StagnationIterationLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_reformulation_bilinear_integer_formulation( self, v: impl Display, ) -> Self

Set GAMS option Model.Reformulation.Bilinear.IntegerFormulation. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_reformulation_bilinear_integer_formulation_max_domain( self, v: impl Display, ) -> Self

Set GAMS option Model.Reformulation.Bilinear.IntegerFormulation.MaxDomain. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_reformulation_constraint_partition_nonlinear_terms( self, v: impl Display, ) -> Self

Set GAMS option Model.Reformulation.Constraint.PartitionNonlinearTerms. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_reformulation_constraint_partition_quadratic_terms( self, v: impl Display, ) -> Self

Set GAMS option Model.Reformulation.Constraint.PartitionQuadraticTerms. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_reformulation_monomials_formulation(self, v: impl Display) -> Self

Set GAMS option Model.Reformulation.Monomials.Formulation. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_reformulation_objective_function_partition_nonlinear_terms( self, v: impl Display, ) -> Self

Set GAMS option Model.Reformulation.ObjectiveFunction.PartitionNonlinearTerms. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_reformulation_objective_function_partition_quadratic_terms( self, v: impl Display, ) -> Self

Set GAMS option Model.Reformulation.ObjectiveFunction.PartitionQuadraticTerms. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_reformulation_quadratics_eigen_value_decomposition_formulation( self, v: impl Display, ) -> Self

Set GAMS option Model.Reformulation.Quadratics.EigenValueDecomposition.Formulation. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_reformulation_quadratics_extract_strategy( self, v: impl Display, ) -> Self

Set GAMS option Model.Reformulation.Quadratics.ExtractStrategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_reformulation_quadratics_strategy(self, v: impl Display) -> Self

Set GAMS option Model.Reformulation.Quadratics.Strategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_bound_tightening_feasibility_based_time_limit( self, v: impl Display, ) -> Self

Set GAMS option Model.BoundTightening.FeasibilityBased.TimeLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_bound_tightening_initial_poa_constraint_tolerance( self, v: impl Display, ) -> Self

Set GAMS option Model.BoundTightening.InitialPOA.ConstraintTolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_bound_tightening_initial_poa_objective_constraint_tolerance( self, v: impl Display, ) -> Self

Set GAMS option Model.BoundTightening.InitialPOA.ObjectiveConstraintTolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_bound_tightening_initial_poa_objective_gap_absolute( self, v: impl Display, ) -> Self

Set GAMS option Model.BoundTightening.InitialPOA.ObjectiveGapAbsolute. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_bound_tightening_initial_poa_objective_gap_relative( self, v: impl Display, ) -> Self

Set GAMS option Model.BoundTightening.InitialPOA.ObjectiveGapRelative. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_bound_tightening_initial_poa_stagnation_constraint_tolerance( self, v: impl Display, ) -> Self

Set GAMS option Model.BoundTightening.InitialPOA.StagnationConstraintTolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_bound_tightening_initial_poa_time_limit( self, v: impl Display, ) -> Self

Set GAMS option Model.BoundTightening.InitialPOA.TimeLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_convexity_quadratics_eigen_value_tolerance( self, v: impl Display, ) -> Self

Set GAMS option Model.Convexity.Quadratics.EigenValueTolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_reformulation_quadratics_eigen_value_decomposition_tolerance( self, v: impl Display, ) -> Self

Set GAMS option Model.Reformulation.Quadratics.EigenValueDecomposition.Tolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_variables_continuous_maximum_upper_bound( self, v: impl Display, ) -> Self

Set GAMS option Model.Variables.Continuous.MaximumUpperBound. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_variables_continuous_minimum_lower_bound( self, v: impl Display, ) -> Self

Set GAMS option Model.Variables.Continuous.MinimumLowerBound. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_variables_integer_maximum_upper_bound( self, v: impl Display, ) -> Self

Set GAMS option Model.Variables.Integer.MaximumUpperBound. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_variables_integer_minimum_lower_bound( self, v: impl Display, ) -> Self

Set GAMS option Model.Variables.Integer.MinimumLowerBound. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_variables_nonlinear_objective_variable_bound( self, v: impl Display, ) -> Self

Set GAMS option Model.Variables.NonlinearObjectiveVariable.Bound. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_bound_tightening_feasibility_based_use( self, v: impl Display, ) -> Self

Set GAMS option Model.BoundTightening.FeasibilityBased.Use. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_bound_tightening_feasibility_based_use_nonlinear( self, v: impl Display, ) -> Self

Set GAMS option Model.BoundTightening.FeasibilityBased.UseNonlinear. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_bound_tightening_initial_poa_use(self, v: impl Display) -> Self

Set GAMS option Model.BoundTightening.InitialPOA.Use. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_convexity_assume_convex(self, v: impl Display) -> Self

Set GAMS option Model.Convexity.AssumeConvex. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_reformulation_bilinear_add_convex_envelope( self, v: impl Display, ) -> Self

Set GAMS option Model.Reformulation.Bilinear.AddConvexEnvelope. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_reformulation_monomials_extract(self, v: impl Display) -> Self

Set GAMS option Model.Reformulation.Monomials.Extract. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_reformulation_objective_function_epigraph_use( self, v: impl Display, ) -> Self

Set GAMS option Model.Reformulation.ObjectiveFunction.Epigraph.Use. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_reformulation_quadratics_eigen_value_decomposition_use( self, v: impl Display, ) -> Self

Set GAMS option Model.Reformulation.Quadratics.EigenValueDecomposition.Use. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn model_reformulation_signomials_extract(self, v: impl Display) -> Self

Set GAMS option Model.Reformulation.Signomials.Extract. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn modeling_system_gams_q_extract_alg(self, v: impl Display) -> Self

Set GAMS option ModelingSystem.GAMS.QExtractAlg. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn modeling_system_gams_q_extract_dense_switch_factor( self, v: impl Display, ) -> Self

Set GAMS option ModelingSystem.GAMS.QExtractDenseSwitchFactor. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn modeling_system_gams_q_extract_dense_switch_log( self, v: impl Display, ) -> Self

Set GAMS option ModelingSystem.GAMS.QExtractDenseSwitchLog. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_fixed_integer_call_strategy(self, v: impl Display) -> Self

Set GAMS option Primal.FixedInteger.CallStrategy. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_fixed_integer_frequency_iteration(self, v: impl Display) -> Self

Set GAMS option Primal.FixedInteger.Frequency.Iteration. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_fixed_integer_iteration_limit(self, v: impl Display) -> Self

Set GAMS option Primal.FixedInteger.IterationLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_fixed_integer_solver(self, v: impl Display) -> Self

Set GAMS option Primal.FixedInteger.Solver. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_fixed_integer_source(self, v: impl Display) -> Self

Set GAMS option Primal.FixedInteger.Source. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_fixed_integer_source_problem(self, v: impl Display) -> Self

Set GAMS option Primal.FixedInteger.SourceProblem. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_fixed_integer_dual_point_gap_relative( self, v: impl Display, ) -> Self

Set GAMS option Primal.FixedInteger.DualPointGap.Relative. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_fixed_integer_frequency_time(self, v: impl Display) -> Self

Set GAMS option Primal.FixedInteger.Frequency.Time. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_fixed_integer_time_limit(self, v: impl Display) -> Self

Set GAMS option Primal.FixedInteger.TimeLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_tolerance_integer(self, v: impl Display) -> Self

Set GAMS option Primal.Tolerance.Integer. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_tolerance_linear_constraint(self, v: impl Display) -> Self

Set GAMS option Primal.Tolerance.LinearConstraint. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_tolerance_nonlinear_constraint(self, v: impl Display) -> Self

Set GAMS option Primal.Tolerance.NonlinearConstraint. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_fixed_integer_create_infeasibility_cut( self, v: impl Display, ) -> Self

Set GAMS option Primal.FixedInteger.CreateInfeasibilityCut. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_fixed_integer_frequency_dynamic(self, v: impl Display) -> Self

Set GAMS option Primal.FixedInteger.Frequency.Dynamic. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_fixed_integer_only_unique_integer_combinations( self, v: impl Display, ) -> Self

Set GAMS option Primal.FixedInteger.OnlyUniqueIntegerCombinations. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_fixed_integer_use(self, v: impl Display) -> Self

Set GAMS option Primal.FixedInteger.Use. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_fixed_integer_warmstart(self, v: impl Display) -> Self

Set GAMS option Primal.FixedInteger.Warmstart. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_rootsearch_use(self, v: impl Display) -> Self

Set GAMS option Primal.Rootsearch.Use. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn primal_tolerance_trust_linear_constraint_values( self, v: impl Display, ) -> Self

Set GAMS option Primal.Tolerance.TrustLinearConstraintValues. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn termination_dual_stagnation_iteration_limit( self, v: impl Display, ) -> Self

Set GAMS option Termination.DualStagnation.IterationLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn termination_iteration_limit(self, v: impl Display) -> Self

Set GAMS option Termination.IterationLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn termination_primal_stagnation_iteration_limit( self, v: impl Display, ) -> Self

Set GAMS option Termination.PrimalStagnation.IterationLimit. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn termination_constraint_tolerance(self, v: impl Display) -> Self

Set GAMS option Termination.ConstraintTolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn termination_dual_stagnation_constraint_tolerance( self, v: impl Display, ) -> Self

Set GAMS option Termination.DualStagnation.ConstraintTolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn termination_objective_constraint_tolerance(self, v: impl Display) -> Self

Set GAMS option Termination.ObjectiveConstraintTolerance. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn termination_objective_gap_absolute(self, v: impl Display) -> Self

Set GAMS option Termination.ObjectiveGap.Absolute. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn termination_objective_gap_relative(self, v: impl Display) -> Self

Set GAMS option Termination.ObjectiveGap.Relative. This solver’s manual declares no type for it, so any Display value is accepted.

pub fn termination_time_limit(self, v: impl Display) -> Self

Set GAMS option Termination.TimeLimit. This solver’s manual declares no type for it, so any Display value is accepted.

Set GAMS option Strategy.UseRecommendedSettings. This solver’s manual declares no type for it, so any Display value is accepted.