pub struct GamsSnoptOptions {
pub raw: Vec<String>,
/* private fields */
}Expand description
Options for GAMS/SNOPT. Reference: https://www.gams.com/latest/docs/S_SNOPT.html
Fields
raw: Vec<String>Extra option-file lines written verbatim, for options without a generated setter (or values a setter can’t express).
Implementations
Sourceimpl GamsSnoptOptions
impl GamsSnoptOptions
Sourcepub fn major_print_level(self, v: i64) -> Self
pub fn major_print_level(self, v: i64) -> Self
Set GAMS option major print level (integer).
Sourcepub fn minor_print_level(self, v: i64) -> Self
pub fn minor_print_level(self, v: i64) -> Self
Set GAMS option minor print level (integer).
Sourcepub fn print_frequency(self, v: i64) -> Self
pub fn print_frequency(self, v: i64) -> Self
Set GAMS option print frequency (integer).
Sourcepub fn summary_frequency(self, v: i64) -> Self
pub fn summary_frequency(self, v: i64) -> Self
Set GAMS option summary frequency (integer).
Sourcepub fn suppress_parameters(self, v: impl Display) -> Self
pub fn suppress_parameters(self, v: impl Display) -> Self
Set GAMS option suppress parameters. This solver’s manual declares no type for it, so any Display value is accepted.
Sourcepub fn timing_level(self, v: i64) -> Self
pub fn timing_level(self, v: i64) -> Self
Set GAMS option timing level (integer).
Sourcepub fn feasible_point(self, v: impl Display) -> Self
pub fn feasible_point(self, v: impl Display) -> Self
Set GAMS option feasible point. This solver’s manual declares no type for it, so any Display value is accepted.
Sourcepub fn infinite_bound(self, v: f64) -> Self
pub fn infinite_bound(self, v: f64) -> Self
Set GAMS option infinite bound (real).
Sourcepub fn major_feasibility_tolerance(self, v: f64) -> Self
pub fn major_feasibility_tolerance(self, v: f64) -> Self
Set GAMS option major feasibility tolerance (real).
Sourcepub fn major_optimality_tolerance(self, v: f64) -> Self
pub fn major_optimality_tolerance(self, v: f64) -> Self
Set GAMS option major optimality tolerance (real).
Sourcepub fn minor_feasibility_tolerance(self, v: f64) -> Self
pub fn minor_feasibility_tolerance(self, v: f64) -> Self
Set GAMS option minor feasibility tolerance (real).
Sourcepub fn verify_level(self, v: i64) -> Self
pub fn verify_level(self, v: i64) -> Self
Set GAMS option verify level (integer).
Sourcepub fn scale_option(self, v: i64) -> Self
pub fn scale_option(self, v: i64) -> Self
Set GAMS option scale option (integer).
Sourcepub fn scale_print(self, v: impl Display) -> Self
pub fn scale_print(self, v: impl Display) -> Self
Set GAMS option scale print. This solver’s manual declares no type for it, so any Display value is accepted.
Sourcepub fn scale_tolerance(self, v: f64) -> Self
pub fn scale_tolerance(self, v: f64) -> Self
Set GAMS option scale tolerance (real).
Sourcepub fn crash_tolerance(self, v: f64) -> Self
pub fn crash_tolerance(self, v: f64) -> Self
Set GAMS option crash tolerance (real).
Sourcepub fn linesearch_tolerance(self, v: f64) -> Self
pub fn linesearch_tolerance(self, v: f64) -> Self
Set GAMS option linesearch tolerance (real).
Sourcepub fn pivot_tolerance(self, v: f64) -> Self
pub fn pivot_tolerance(self, v: f64) -> Self
Set GAMS option pivot tolerance (real).
Sourcepub fn crash_option(self, v: i64) -> Self
pub fn crash_option(self, v: i64) -> Self
Set GAMS option crash option (integer).
Sourcepub fn elastic_weight(self, v: f64) -> Self
pub fn elastic_weight(self, v: f64) -> Self
Set GAMS option elastic weight (real).
Sourcepub fn iterations_limit(self, v: i64) -> Self
pub fn iterations_limit(self, v: i64) -> Self
Set GAMS option iterations limit (integer).
Sourcepub fn partial_price(self, v: i64) -> Self
pub fn partial_price(self, v: i64) -> Self
Set GAMS option partial price (integer).
Sourcepub fn central_difference_interval(self, v: f64) -> Self
pub fn central_difference_interval(self, v: f64) -> Self
Set GAMS option central difference interval (real).
Sourcepub fn cold_start(self, v: impl Display) -> Self
pub fn cold_start(self, v: impl Display) -> Self
Set GAMS option cold start. This solver’s manual declares no type for it, so any Display value is accepted.
Sourcepub fn derivative_linesearch(self, v: impl Display) -> Self
pub fn derivative_linesearch(self, v: impl Display) -> Self
Set GAMS option derivative linesearch. This solver’s manual declares no type for it, so any Display value is accepted.
Sourcepub fn difference_interval(self, v: f64) -> Self
pub fn difference_interval(self, v: f64) -> Self
Set GAMS option difference interval (real).
Sourcepub fn function_precision(self, v: f64) -> Self
pub fn function_precision(self, v: f64) -> Self
Set GAMS option function precision (real).
Sourcepub fn major_iterations_limit(self, v: i64) -> Self
pub fn major_iterations_limit(self, v: i64) -> Self
Set GAMS option major iterations limit (integer).
Sourcepub fn major_step_limit(self, v: f64) -> Self
pub fn major_step_limit(self, v: f64) -> Self
Set GAMS option major step limit (real).
Sourcepub fn minor_iterations_limit(self, v: i64) -> Self
pub fn minor_iterations_limit(self, v: i64) -> Self
Set GAMS option minor iterations limit (integer).
Sourcepub fn new_superbasics_limit(self, v: i64) -> Self
pub fn new_superbasics_limit(self, v: i64) -> Self
Set GAMS option new superbasics limit (integer).
Sourcepub fn nonderivative_linesearch(self, v: impl Display) -> Self
pub fn nonderivative_linesearch(self, v: impl Display) -> Self
Set GAMS option nonderivative linesearch. This solver’s manual declares no type for it, so any Display value is accepted.
Sourcepub fn penalty_parameter(self, v: f64) -> Self
pub fn penalty_parameter(self, v: f64) -> Self
Set GAMS option penalty parameter (real).
Sourcepub fn proximal_point_method(self, v: i64) -> Self
pub fn proximal_point_method(self, v: i64) -> Self
Set GAMS option proximal point method (integer).
Sourcepub fn reduced_hessian_dimension(self, v: i64) -> Self
pub fn reduced_hessian_dimension(self, v: i64) -> Self
Set GAMS option reduced hessian dimension (integer).
Sourcepub fn superbasics_limit(self, v: i64) -> Self
pub fn superbasics_limit(self, v: i64) -> Self
Set GAMS option superbasics limit (integer).
Sourcepub fn unbounded_objective_value(self, v: f64) -> Self
pub fn unbounded_objective_value(self, v: f64) -> Self
Set GAMS option unbounded objective value (real).
Sourcepub fn unbounded_step_size(self, v: f64) -> Self
pub fn unbounded_step_size(self, v: f64) -> Self
Set GAMS option unbounded step size (real).
Sourcepub fn violation_limit(self, v: i64) -> Self
pub fn violation_limit(self, v: i64) -> Self
Set GAMS option violation limit (integer).
Sourcepub fn warm_start(self, v: impl Display) -> Self
pub fn warm_start(self, v: impl Display) -> Self
Set GAMS option warm start. This solver’s manual declares no type for it, so any Display value is accepted.
Sourcepub fn hessian_frequency(self, v: i64) -> Self
pub fn hessian_frequency(self, v: i64) -> Self
Set GAMS option hessian frequency (integer).
Sourcepub fn hessian_full_memory(self, v: impl Display) -> Self
pub fn hessian_full_memory(self, v: impl Display) -> Self
Set GAMS option hessian full memory. This solver’s manual declares no type for it, so any Display value is accepted.
Sourcepub fn hessian_limited_memory(self, v: impl Display) -> Self
pub fn hessian_limited_memory(self, v: impl Display) -> Self
Set GAMS option hessian limited memory. This solver’s manual declares no type for it, so any Display value is accepted.
Sourcepub fn hessian_updates(self, v: i64) -> Self
pub fn hessian_updates(self, v: i64) -> Self
Set GAMS option hessian updates (integer).
Sourcepub fn check_frequency(self, v: i64) -> Self
pub fn check_frequency(self, v: i64) -> Self
Set GAMS option check frequency (integer).
Sourcepub fn expand_frequency(self, v: i64) -> Self
pub fn expand_frequency(self, v: i64) -> Self
Set GAMS option expand frequency (integer).
Sourcepub fn factorization_frequency(self, v: i64) -> Self
pub fn factorization_frequency(self, v: i64) -> Self
Set GAMS option factorization frequency (integer).
Sourcepub fn lu_complete_pivoting(self, v: impl Display) -> Self
pub fn lu_complete_pivoting(self, v: impl Display) -> Self
Set GAMS option LU complete pivoting. This solver’s manual declares no type for it, so any Display value is accepted.
Sourcepub fn lu_density_tolerance(self, v: f64) -> Self
pub fn lu_density_tolerance(self, v: f64) -> Self
Set GAMS option LU density tolerance (real).
Sourcepub fn lu_factor_tolerance(self, v: f64) -> Self
pub fn lu_factor_tolerance(self, v: f64) -> Self
Set GAMS option LU factor tolerance (real).
Sourcepub fn lu_partial_pivoting(self, v: impl Display) -> Self
pub fn lu_partial_pivoting(self, v: impl Display) -> Self
Set GAMS option LU partial pivoting. This solver’s manual declares no type for it, so any Display value is accepted.
Sourcepub fn lu_rook_pivoting(self, v: impl Display) -> Self
pub fn lu_rook_pivoting(self, v: impl Display) -> Self
Set GAMS option LU rook pivoting. This solver’s manual declares no type for it, so any Display value is accepted.
Sourcepub fn lu_singularity_tolerance(self, v: f64) -> Self
pub fn lu_singularity_tolerance(self, v: f64) -> Self
Set GAMS option LU singularity tolerance (real).
Sourcepub fn lu_update_tolerance(self, v: f64) -> Self
pub fn lu_update_tolerance(self, v: f64) -> Self
Set GAMS option LU update tolerance (real).
Sourcepub fn solution(self, v: GamsSnoptSolution) -> Self
pub fn solution(self, v: GamsSnoptSolution) -> Self
Set GAMS option solution, restricted to its documented values.
Sourcepub fn system_information(self, v: GamsSnoptSystemInformation) -> Self
pub fn system_information(self, v: GamsSnoptSystemInformation) -> Self
Set GAMS option system information, restricted to its documented values.
Sourcepub fn qpsolver(self, v: GamsSnoptQpsolver) -> Self
pub fn qpsolver(self, v: GamsSnoptQpsolver) -> Self
Set GAMS option qpsolver, restricted to its documented values.